@@ -17,7 +17,7 @@ impl GroupFs {
     pub fn new(header: Option<String>) -> Self {
         let header = header.unwrap_or_else(|| String::from("File System Group"));
         let unit = String::new();
-        GroupFs {
+        Self {
             fmt_contents: HashMap::new(),
             raw_contents: HashMap::new(),
             width: 0,
